*Set up workspace
set more off

/**********************************************************************************************************
* Load and recode NAES 2000 data used in analysis
**********************************************************************************************************

Notes:
Compile any NAES 2000 datasets that contain unique respondents for questions CR46-CR51 (C prefix is cross section, R prefix is for panel interview #2

(For questions R46-R49:) Please tell me if you strongly agree, somewhat agree, somewhat disagree or strongly disagree: 
R46. The people I know vote in almost every election. Q409b
R47. If I do not vote, my family and friends are disappointed in me. Q409a
R48. If I do not vote, I feel guilty. Q409d
R49. If I do not vote, I feel less like an American. Q409c
R50. When you do vote do you usually get a feeling of satisfaction from it, or do you only do it because it's your duty? Q374
R51. Would you say voting is one of the most important responsibilities of being an American, very important, somewhat important or not too important? Q375

Containing datasets:
CS010119 -- CR46-49
ELECPNL -- RR46-49 
*/

local commonvars =      "cint ckey cdate cst CR30 CR34 CR46 CR47 CR48 CR49 CV01 CV02 CV03 CV04 CW01 CW02 CW03 CW04 CW06 CW07 CW09 CW14 CW18 CW23 CW28 CY06"
local commonvarspanel = "rint rkey rdate rst RR30 RR34 RR46 RR47 RR48 RR49 RV01 RV02 RV03 RV04 RY06"

*Load relevant panel and cross sectional dataset (coverage of CR46/RR46)
use "..\..\NotInReplicationArchive\NAEScomplete_datasets\ELECPNL.DTA"
qui append using "..\..\NotInReplicationArchive\NAEScomplete_datasets\CS010119.DTA"
keep `commonvars' `commonvarspanel'
isid ckey
qui compress

rename CW23 fipsindx
drop if fipsindx==.
label variable fipsindx "County FIPSINDX"

*Recode each of 4 survey measures, changing order, and using panel observation if cross-sectional response is missing
label define agreescaleflippedlabel 0 "Strongly Disagree" 1 "Somewhat Disagree" 2 "Somewhat Agree" 3 "Strongly Agree"
foreach num of numlist 46 47 48 49 { 
 recode CR`num' (1=1) (2=.666) (3=.333) (4=0) (*=.), gen (recode_cr`num')
 recode RR`num' (1=1) (2=.666) (3=.333) (4=0) (*=.), gen (recode_rr`num')
 local templbl : variable label CR`num'
 label var recode_cr`num' "`templbl'"
 label var recode_rr`num' "`templbl'"
}

label var recode_cr46 "People I know vote (0-1)"
label var recode_cr47 "Family and friends disappointed if I don't vote (0-1)"
label var recode_cr48 "If I do not vote, I feel guilty (0-1)"
label var recode_cr49 "If I do not vote, I feel less American (0-1)"
 
gen usepanel=0
egen missing4649=rowmiss(recode_cr46 recode_cr47 recode_cr48 recode_cr49)
egen missingR4649=rowmiss(recode_rr46 recode_rr47 recode_rr48 recode_rr49)
keep if missing4649==0 | missingR4649==0
replace usepanel=1 if missing4649==4
drop missing4649 missingR4649 rint rkey rst 

*For cases where we have to use the second interview to get the norms measures, replace the cross sectional variables with the 2nd interview measure 
replace cdate=rdate if usepanel==1
foreach var in R30 R34 R46 R47 R48 R49 V01 V02 V03 V04 Y06 {
 replace C`var'=R`var' if usepanel==1
 drop R`var'
} 

foreach num of numlist 46 47 48 49 {
 replace recode_cr`num'=recode_rr`num' if usepanel==1
 drop recode_rr`num'
 }

*keep only observations with valid county code
drop if fipsindx==.
compress

recode CW01 (1=0) (2=1) (*=.), gen(d_female)
label var d_female "Female (1=yes)"
drop CW01

recode CW02 (900/max=.), gen (d_age)
label var d_age "Age in years"
gen d_age2=d_age^2/100
label var d_age2 "Age in years squared/100"
drop CW02

recode CW03 (2=1) (900/max=.) (*=0), gen(d_black)
label var d_black "Black (1=yes)"
recode CW04 (1=1) (2=0) (900/max=.) (*=.), gen(d_hispanic)
label var d_hispanic "Hispanic (1=yes)"
drop CW03 CW04

recode CW06 (1=0) (2=0) (3=1) (4=1) (5=1) (6=2) (7=3) (8=3) (9=4) (*=.), gen(d_educ)
label var d_educ "Education Scale (0-4)"
drop CW06

*Restrict to US citizens
drop if CW07~=1
drop CW07

recode CW14 (1=4) (2=3) (3=2) (4=1) (5=0) (*=.), gen(d_church)
label var d_church "Attend church scale (0-4)"
drop CW14

recode CW18 (0=1) (900/max=.) (.=.), gen(d_yearsataddress)
replace d_yearsataddress = log(d_yearsataddress )
label var d_yearsataddress "Log years at current address"
drop CW18

recode CW28 (998=10) (999=10), gen(d_income)
gen d_incrfdk=d_income==10
drop CW28
label var d_income "Income scale (1-9, 10=DKRF)"
label var d_incrfdk "Income Refused/Don't know"

gen year=int(cdate/10000)
gen month=int(cdate/100)-year*100
gen day=cdate-int(cdate/100)*100
drop cdate

recode CR34 (1=1) (2=0) (3=0) (4=0) (*=.), gen(voted)
label var voted "Voted in general (1=yes), retrospective recall"
drop CR34

gen pid7=0
replace pid7=-3 if CV01==1 & CV02==1
replace pid7=-2 if CV01==1 & CV02~=1
replace pid7=-1 if (CV01~=1 & CV02~=2) & CV03==1
replace pid7=3 if CV01==2 & CV02==1
replace pid7=2 if CV01==2 & CV02~=1
replace pid7=1 if (CV01~=1 & CV02~=2) & CV03==2
drop CV01 CV02 CV03
label var pid7 "Party-ID (-3 S. Rep, +3 S. Dem)"
tab pid7, gen(pidcat_)
drop pidcat_4

*State fixed effects
gen statenum=int(fipsindx/1000)

tab d_educ, gen(f_educcat)
drop f_educcat1
rename d_educ dd_educ

tab d_church, gen(f_churchcat)
drop f_churchcat1
rename d_church dd_chuch

tab d_income, gen(f_incomecat)
drop f_incomecat1
rename d_income dd_income
rename d_incrfdk dd_incrfdk

compress
save data/NAESRecoded.dta, replace
