#
# socialReturnsMRP.R
#
# Calculate county-level estimates of social returns
# covariates using multilevel regression with post-
# stratification. Outputs dta file with county-level
# estimates.
#
# Seth Hill, November 2011
# Edited by Greg Huber, 12/2013
#

rm(list = ls())
# Need to update PATH here
setwd("C:/Users/GAHUBER/Desktop/SRVMRP")
library(foreign)
library(arm)

#
# Individual data from Annenberg 2000 survey for respondents
# who answered questions of interest in either the cross-section
# or in the panel study. File created by 01_PrepareReplicationArchive.do
#
dat <- read.dta(file.path("Data","NAESRecoded.dta"),
        convert.underscore=TRUE)
census.dat <- read.dta(file.path("Data","CountyDemographicsForMRPEstimates.dta"),convert.underscore=TRUE)
        
# Create Census variables that match to those that will be raked to in the
# post-stratification phase: gender (female, male) crossed with race (black,
# hispanic, other) crossed with age cat (20-29, 30-44, 45-64, 65+).

less.than.20 <- with(dat,is.na(d.age) | d.age < 20)
cat("Dropping",sum(less.than.20),"respondents missing age or less than 20.\n")
dat <- dat[!less.than.20,]
missing.race <- with(dat,is.na(d.black) | is.na(d.hispanic))
cat("Dropping",sum(missing.race),"respondents missing race.\n")
dat <- dat[!missing.race,]
bad.fips <- dat$fipsindx == "51560"
cat("Dropping",sum(bad.fips),"respondents with a bad FIPS.\n")
dat <- dat[!bad.fips,]

dat$race.cat <- with(dat,ifelse(d.black == 1,"black",ifelse(d.hispanic == 1,"hispanic","other")))
dat$age.cat <- with(dat,ifelse(d.age < 30,"20-29",ifelse(d.age < 45,"30-44",
                        ifelse(d.age < 65,"45-64","65+"))))
dat$stratum <- with(dat,sprintf("%s|%s|%s",ifelse(d.female == 1,"female","male"),race.cat,age.cat))
stratum.tab <- with(dat,table(stratum))
cat("Distribution of stratum counts:\n")
print(summary(c(stratum.tab)))

# County, state, and region (todo).
dat[,"state"] <- with(dat,substr(sprintf("%05.0f",fipsindx),1,2))

#
# Run individual-level models: hierarchical models with individual level
# predictors along with county and state random effects.
#
res <- list()
for (dv in c("recode.cr46","recode.cr47","recode.cr48","recode.cr49","factor1")) {
  res[[dv]] <- lmer(formula=as.formula(paste(dv,"~ (1|stratum) + (1|age.cat) + (1|fipsindx) + (1|state)")),
                    data=dat)
  cat("\n=============================\nModel result for",dv,":\n")
  print(summary(res[[dv]])) ; flush.console()
}

#
# Create county prediction from each model given county-level census data.
# Estimates are weighted through post-stratification.
#

# Common Census variables.
names(census.dat)[regexpr("newagecat",names(census.dat)) != -1] <- "age.cat"
census.dat[,'race.cat'] <- sapply(census.dat$group,function(x) unlist(strsplit(x,"_"))[1])
census.dat[census.dat$race.cat == "white",'race.cat'] <- "other"
census.dat[,'gender'] <- sapply(census.dat$group,function(x) unlist(strsplit(x,"_"))[2])
census.dat$stratum <- with(census.dat,sprintf("%s|%s|%s",gender,race.cat,age.cat))
census.dat$fipsindx <- with(census.dat,sprintf("%s%03.0f",state,county))
census.dat$state <- sprintf("%02.0f",census.dat$state) # To match in dat.

cat("Tabulation of matches from NAES data to Census data:\n")
print(table(unique(dat$fipsindx) %in% unique(census.dat$fipsindx)))
cat("NAES FIPS not in Census FIPS:\n")
print(sort(unique(dat$fipsindx)[!unique(dat$fipsindx) %in% unique(census.dat$fipsindx)]))

post.strat.predict <- function(county.dat,mer,rvars=c("stratum","age.cat","fipsindx","state")) {
  # Calculate predicted values for a county data frame given a model result and county variables.
  coefs <- matrix(NA,nrow=nrow(county.dat),ncol=length(rvars)+1)
  colnames(coefs) <- c("intercept",rvars)
  coefs[,1] <- rep(fixef(mer),nrow(county.dat)) # Global intercept.
  for (rv in rvars) {
    ran.efs <- ranef(mer)[[rv]]
    coefs[,rv] <- ran.efs[match(county.dat[,rv],rownames(ran.efs)),] # Match appropriate random effect.
  }
  # Assuming a linear model, predicted values are the row sums.
  return(rowSums(coefs)) # Note: any missing predictor will yield a missing result.
}

for (dv in names(res)) {
  census.dat[,dv] <- post.strat.predict(census.dat,res[[dv]])
}
print(summary(census.dat))

# Aggregate up to the county.
agg.vars <- names(res)
# Weight by the count.
for (dv in agg.vars) { census.dat[,dv] <- census.dat[,dv]*census.dat[,'count'] }
county.estimates <- aggregate(census.dat[,c(agg.vars,"count")],by=list("fipsindx"=census.dat$fipsindx),
                              FUN=sum)
# Divide by count to get back to weighted average.
for (dv in agg.vars) { county.estimates[,dv] <- county.estimates[,dv]/county.estimates[,'count'] }

# Add in the number of cases used for each county.
county.counts <- table(dat$fipsindx)
county.estimates[,'respondents.used.in.county'] <- county.counts[match(county.estimates$fipsindx,
                                                                  names(county.counts))]
# Failure to merge means 0 NAES respondents in county.
county.estimates[is.na(county.estimates$respondents.used.in.county),'respondents.used.in.county'] <- 0
# Write out to Stata.
write.dta(county.estimates,file="Data/CountySocialReturnsMrPEstimates.dta",version=9)
